@@ -29,6 +29,7 @@ from turbinia import config
 from turbinia.config import logger
 from turbinia.lib import libcloudforensics
 from turbinia import __version__
+from turbinia.processors import archive
 
 log = logging.getLogger('turbinia')
 # We set up the logger first without the file handler, and we will set up the
@@ -276,6 +277,17 @@ def main():
   parser_directory.add_argument(
       '-n', '--name', help='Descriptive name of the evidence', required=False)
 
+  # Parser options for CompressedDirectory evidence type
+  parser_compressed_directory = subparsers.add_parser(
+      'compressedirectory', help='Process a compressed tar file as Evidence')
+  parser_compressed_directory.add_argument(
+      '-l', '--local_path', help='Local path to the evidence', required=True)
+  parser_compressed_directory.add_argument(
+      '-s', '--source', help='Description of the source of the evidence',
+      required=False)
+  parser_compressed_directory.add_argument(
+      '-n', '--name', help='Descriptive name of the evidence', required=False)
+
   # Parser options for ChromiumProfile evidence type
   parser_hindsight = subparsers.add_parser(
       'hindsight', help='Process ChromiumProfile as Evidence')
@@ -497,6 +509,12 @@ def main():
     local_path = os.path.abspath(args.local_path)
     evidence_ = evidence.Directory(
         name=args.name, local_path=local_path, source=args.source)
+  elif args.command == 'compressedirectory':
+    archive.ValidateTarFile(args.source_path)
+    args.name = args.name if args.name else args.source_path
+    source_path = os.path.abspath(args.source_path)
+    evidence_ = evidence.CompressedDirectory(
+        name=args.name, source_path=source_path, source=args.source)
   elif args.command == 'googleclouddisk':
     args.name = args.name if args.name else args.disk_name
     evidence_ = evidence.GoogleCloudDisk(
